@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2010-2017 The pygit2 contributors
+# Copyright 2010-2019 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -37,7 +37,7 @@ from os import getenv
 #
 # The version number of pygit2
 #
-__version__ = '0.27.2'
+__version__ = '0.28.2'
 
 
 #
@@ -51,7 +51,7 @@ def _get_libgit2_path():
 
     # Default
     if os.name == 'nt':
-        return '%s\libgit2' % getenv("ProgramFiles")
+        return r'%s\libgit2' % getenv("ProgramFiles")
     return '/usr/local'
 
 
